@@ -11,7 +11,6 @@ from typing import Dict
 from typing import Generator
 from typing import List
 from typing import Optional
-from typing import Set
 
 import hyperthought as ht
 from hyperthought.metadata import MetadataItem
@@ -437,18 +436,25 @@ class Manifest:
         # Create all records.
         self.database.bulk_load_files(file_data=file_data)
 
-    def add_paths(self, paths: List[str]) -> None:
+    def add_paths(
+        self,
+        paths: List[str],
+        parser_class_name: Optional[str] = None,
+    ) -> None:
         """
         Add paths to the manifest.
 
         Ancestor folders will be created as needed.
         """
-        # TODO:  Make paths type generic. ^^^
+        # TODO:  Make paths type generic.  (Any sequence, not just lists.)
         paths = {utils.clean_path(path) for path in paths}
 
         for path in paths:
             self._validate_path(path)
 
+        if parser_class_name is not None:
+            self._validate_parser(parser_class_name=parser_class_name)
+
         len_ignorepath = (
             0
             if self._ignore_path is None
@@ -506,9 +512,59 @@ class Manifest:
                 "file_hash": None,
             })
 
-        # Create all records.
+        # Create all file records.
+        # NOTE:  file ids will be added in place by the bulk load method.
         self.database.bulk_load_files(file_data=file_data)
 
+        if parser_class_name:
+            parser_class = ht.parsers.get(parser_class_name)
+
+            # There will be a 1:1 correspondence between the following lists.
+            # Metadata records will be created first.
+            # Then the ids for the metadata records, which will be added
+            # to the list items in place by the bulk_load_metadata database
+            # function, will be added to the entries in the other lists.
+            metadata_data = []
+            parser_data = []
+            metadata_application_data = []
+
+            for file_item in file_data:
+                file_extension = (
+                    os.path.splitext(file_item["path"])[-1].strip("."))
+
+                if parser_class.is_valid_extension(file_extension):
+                    metadata_data.append({
+                        "metadata": None,
+                    })
+                    parser_data.append({
+                        "file_id": file_item["id"],
+                        "parser_class": parser_class_name,
+                        "metadata_id": None
+                    })
+                    metadata_application_data.append({
+                        "metadata_id": None,
+                        "file_id": file_item["id"],
+                    })
+
+            self.database.bulk_load_metadata(metadata_data=metadata_data)
+
+            for index in range(len(metadata_data)):
+                metadata_item = metadata_data[index]
+
+                if "id" not in metadata_item or metadata_item["id"] is None:
+                    raise Exception(
+                        "ids not added in place via call to "
+                        "database.bulk_load_metadata"
+                    )
+
+                parser_data[index]["metadata_id"] = metadata_item["id"]
+                metadata_application_data[index]["metadata_id"] = (
+                    metadata_item["id"])
+
+            self.database.bulk_load_parsers(parser_data=parser_data)
+            self.database.bulk_load_metadata_application(
+                metadata_application_data=metadata_application_data)
+
     def remove_path(self, path: str) -> None:
         """
         Remove a path from the manifest.
